@@ -98,7 +98,7 @@ set_lang (void)
   char *short_lang;
   char *p;
 
-  gdm_lang = getenv("GDM_LANG");
+  gdm_lang = g_getenv("GDM_LANG");
   if (gdm_lang)
     {
       short_lang = g_strdup (gdm_lang);
@@ -126,6 +126,7 @@ main (int argc, char *argv[])
   gboolean splashing;
   char *ep;
   poptContext ctx;
+  char *session_name_env;
   Session *the_session;
   
   set_lang();
@@ -160,7 +161,16 @@ main (int argc, char *argv[])
   gnome_config_push_prefix (GSM_OPTION_CONFIG_PREFIX);
   splashing = gnome_config_get_bool (SPLASH_SCREEN_KEY "=" SPLASH_SCREEN_DEFAULT);
   autosave = gnome_config_get_bool (AUTOSAVE_MODE_KEY "=" AUTOSAVE_MODE_DEFAULT);
-  
+ 
+
+  /* If the session wasn't set on the command line, but we see a
+   * GDM_GNOME_SESSION env var, use that.  The user is using the GDM chooser
+   */
+  if (session_name == NULL &&
+      g_getenv ("GDM_GNOME_SESSION") != NULL) {
+    session_name = g_strdup (g_getenv ("GDM_GNOME_SESSION"));
+  }
+
   /* If the session name hasn't been specified from the command line */ 
   if(session_name == NULL) {
 	/* If there is no key specified, fall back to the default session */	
@@ -170,8 +180,10 @@ main (int argc, char *argv[])
   gnome_config_pop_prefix ();
    
   if(failsafe)
-	session_name = DEFAULT_SESSION;
+	session_name = FAILSAFE_SESSION;
   
+  session_name_env = g_strconcat ("GNOME_SESSION_NAME=", g_strdup (session_name), NULL);
+  putenv (session_name_env);
   the_session = read_session (session_name);
 
   if (splashing)
